#
# spec file for package ghc-mime-types
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name mime-types
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        0.1.2.0
Release:        1.3
Summary:        Basic mime-type handling types and functions
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
ExcludeArch:    %{ix86}

%description
API docs and the README are available at
<http://www.stackage.org/package/mime-types>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Wed Oct 18 2023 Peter Simons <psimons@suse.com>
- Update mime-types to version 0.1.2.0.
  [#]# 0.1.2.0
  * Added `defaultExtensionMap` to provide the inverse of `defaultMimeMap`.
  See PR [#930](https://github.com/yesodweb/wai/pull/930) and [#948](https://github.com/yesodweb/wai/pull/948).
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sun Sep 11 2022 Peter Simons <psimons@suse.com>
- Update mime-types to version 0.1.1.0.
  [#]# 0.1.1.0
  * Replace `audio/x-mpegurl` with IANA registered type
    `application/vnd.apple.mpegurl`.
  * Add TeX-related types; this includes `bib`, `tex`, `sty`, and `cls`.
  * Use type image/x-xcf for `.xcf` files.
  * Use type "audio/opus" for `.opus` files.
  * Add type text/vtt for `.vtt` text track files.
  * Use IANA registered type "application/vnd.rar" for `.rar` files.
  * Use font types defined in RFC 8081.
  * Replace `audio/x-m4a` with `audio/mp4`.
  * Change mime type for `.exe` files; use IANA registered type
    `application/vnd.microsoft.portable-executable`.
  * Add `video/dv` for files with extension `dv`.
  * Use 'application/xml' instead of 'text/xml'.
  * Change type for `.pcx` files to `image/vnd.zbrush.pcx`.
  * Use `text/markdown` type for `.md` and `.markdown` files.
  * Replace `application/x-gzip` with type `application/gzip`.
  See PR [#906](https://github.com/yesodweb/wai/pull/906).
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Mon Dec 24 2018 psimons@suse.com
- Update mime-types to version 0.1.0.9.
  [#]# 0.1.0.9
  * Add mjs mime type
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update mime-types to version 0.1.0.8.
  [#]# 0.1.0.8
  * Add wasm mime type
* Wed May 16 2018 psimons@suse.com
- Prefer the new %%license attribute over %%doc.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.1.0.7 revision 0 with cabal2obs.
* Tue Apr 26 2016 mimi.vx@gmail.com
- update to 0.1.0.7
  * Add support for .less files
* Wed Apr 22 2015 mimi.vx@gmail.com
- update to 0.1.0.6
  * Add woff2 mime type
* Mon Oct  7 2013 sbahling@suse.com
- Initial package - version 0.1.0.3
